Index: src/heap.h |
=================================================================== |
--- src/heap.h (revision 2724) |
+++ src/heap.h (working copy) |
@@ -627,8 +627,9 @@ |
// Returns whether required_space bytes are available after the collection. |
static bool CollectGarbage(int required_space, AllocationSpace space); |
- // Performs a full garbage collection. |
- static void CollectAllGarbage(); |
+ // Performs a full garbage collection. Force compaction if the |
+ // parameter is true. |
+ static void CollectAllGarbage(bool force_compaction = false); |
// Performs a full garbage collection if a context has been disposed |
// since the last time the check was performed. |